#[non_exhaustive]pub enum WideScopeSubscription {
OrganizationSubscription(Box<OrganizationSubscription>),
ProjectSubscriptions(Box<ProjectSubscriptions>),
}Expand description
Config to enabled subscribing to events from other projects in the org.
Users need the eventarc.googleApiSource.create permission on the entire org in order to create a resource with these settings.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OrganizationSubscription(Box<OrganizationSubscription>)
Optional. Config to enable subscribing to events from all projects in the GoogleApiSource’s org.
ProjectSubscriptions(Box<ProjectSubscriptions>)
Optional. Config to enable subscribing to all events from a list of projects.
All the projects must be in the same org as the GoogleApiSource.