#[non_exhaustive]pub struct ProjectSubscriptions {
pub list: Vec<String>,
/* private fields */
}Expand description
Config to enable subscribing to all events from a list of projects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.list: Vec<String>Required. A list of projects to receive events from.
All the projects must be in the same org. The listed projects should have the format project/{identifier} where identifier can be either the project id for project number. A single list may contain both formats. At most 100 projects can be listed.
Implementations