HttpEndpoint

Struct HttpEndpoint 

#[non_exhaustive]
pub struct HttpEndpoint { pub uri: String, /* private fields */ }
Represents a HTTP endpoint destination.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
uri: String

Required. The URI of the HTTP endpoint.

The value must be a RFC2396 URI string. Examples: http://10.10.10.8:80/route, <http://svc.us-central1.p.local>:8080/. Only HTTP and HTTPS protocols are supported. The host can be either a static IP addressable from the VPC specified by the network config, or an internal DNS hostname of the service resolvable via Cloud DNS.

Implementations

Source

impl HttpEndpoint

pub fn new() -> Self

Creates a new default instance.

pub fn set_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of uri.

Example
let x = HttpEndpoint::new().set_uri("example");